| Copyright | (c) 2013-2023 Brendan Hay |
|---|---|
| License | Mozilla Public License, v. 2.0. |
| Maintainer | Brendan Hay |
| Stability | auto-generated |
| Portability | non-portable (GHC extensions) |
| Safe Haskell | Safe-Inferred |
| Language | Haskell2010 |
Amazonka.GuardDuty.Types.FilterCriteria
Description
Synopsis
Documentation
data FilterCriteria Source #
Represents the criteria to be used in the filter for describing scan entries.
See: newFilterCriteria smart constructor.
Constructors
| FilterCriteria' | |
Fields
| |
Instances
newFilterCriteria :: FilterCriteria Source #
Create a value of FilterCriteria with all optional fields omitted.
Use generic-lens or optics to modify other optional fields.
The following record fields are available, with the corresponding lenses provided for backwards compatibility:
$sel:filterCriterion:FilterCriteria', filterCriteria_filterCriterion - Represents a condition that when matched will be added to the response
of the operation.
filterCriteria_filterCriterion :: Lens' FilterCriteria (Maybe [FilterCriterion]) Source #
Represents a condition that when matched will be added to the response of the operation.